@@ -5,7 +5,7 @@ use warnings;
 package Path::Tiny;
 # ABSTRACT: File path utility
 
-our $VERSION = '0.065';
+our $VERSION = '0.068';
 
 # Dependencies
 use Config;
@@ -772,20 +772,26 @@ sub is_dir { -d $_[0]->[PATH] }
 #pod
 #pod     $fh = path("/tmp/foo.txt")->filehandle($mode, $binmode);
 #pod     $fh = path("/tmp/foo.txt")->filehandle({ locked => 1 }, $mode, $binmode);
+#pod     $fh = path("/tmp/foo.txt")->filehandle({ exclusive => 1  }, $mode, $binmode);
 #pod
 #pod Returns an open file handle.  The C<$mode> argument must be a Perl-style
 #pod read/write mode string ("<" ,">", "<<", etc.).  If a C<$binmode>
 #pod is given, it is set during the C<open> call.
 #pod
-#pod An optional hash reference may be used to pass options.  The only option is
-#pod C<locked>.  If true, handles opened for writing, appending or read-write are
-#pod locked with C<LOCK_EX>; otherwise, they are locked with C<LOCK_SH>.  When using
-#pod C<locked>, ">" or "+>" modes will delay truncation until after the lock is
-#pod acquired.
+#pod An optional hash reference may be used to pass options.
+#pod
+#pod The C<locked> option governs file locking; if true, handles opened for writing,
+#pod appending or read-write are locked with C<LOCK_EX>; otherwise, they are
+#pod locked with C<LOCK_SH>.  When using C<locked>, ">" or "+>" modes will delay
+#pod truncation until after the lock is acquired.
+#pod
+#pod The C<exclusive> option causes the open() call to fail if the file already
+#pod exists.  This corresponds to the O_EXCL flag to sysopen / open(2).
+#pod C<exclusive> implies C<locked> and will set it for you if you forget it.
 #pod
 #pod See C<openr>, C<openw>, C<openrw>, and C<opena> for sugar.
 #pod
-#pod Current API available since 0.039.
+#pod Current API available since 0.066.
 #pod
 #pod =cut
 
@@ -795,7 +801,8 @@ sub is_dir { -d $_[0]->[PATH] }
 sub filehandle {
     my ( $self, @args ) = @_;
     my $args = ( @args && ref $args[0] eq 'HASH' ) ? shift @args : {};
-    $args = _get_args( $args, qw/locked/ );
+    $args = _get_args( $args, qw/locked exclusive/ );
+    $args->{locked} = 1 if $args->{exclusive};
     my ( $opentype, $binmode ) = @args;
 
     $opentype = "<" unless defined $opentype;
@@ -814,6 +821,7 @@ sub filehandle {
             # sysopen in write mode without truncation
             my $flags = $opentype eq ">" ? Fcntl::O_WRONLY() : Fcntl::O_RDWR();
             $flags |= Fcntl::O_CREAT();
+            $flags |= Fcntl::O_EXCL() if $args->{exclusive};
             sysopen( $fh, $self->[PATH], $flags ) or $self->_throw("sysopen");
 
             # fix up the binmode since sysopen() can't specify layers like
@@ -1488,7 +1496,7 @@ sub spew {
     # get default binmode from caller's lexical scope (see "perldoc open")
     $binmode = ( ( caller(0) )[10] || {} )->{'open>'} unless defined $binmode;
     my $temp = path( $self->[PATH] . $$ . int( rand( 2**31 ) ) );
-    my $fh = $temp->filehandle( ">", $binmode );
+    my $fh = $temp->filehandle( { exclusive => 1, locked => 1 }, ">", $binmode );
     print {$fh} map { ref eq 'ARRAY' ? @$_ : $_ } @data;
     close $fh or $self->_throw( 'close', $temp->[PATH] );
 
@@ -1773,7 +1781,7 @@ Path::Tiny - File path utility
 
 =head1 VERSION
 
-version 0.065
+version 0.068
 
 =head1 SYNOPSIS
 
@@ -2157,20 +2165,26 @@ Current API available since 0.053.
 
     $fh = path("/tmp/foo.txt")->filehandle($mode, $binmode);
     $fh = path("/tmp/foo.txt")->filehandle({ locked => 1 }, $mode, $binmode);
+    $fh = path("/tmp/foo.txt")->filehandle({ exclusive => 1  }, $mode, $binmode);
 
 Returns an open file handle.  The C<$mode> argument must be a Perl-style
 read/write mode string ("<" ,">", "<<", etc.).  If a C<$binmode>
 is given, it is set during the C<open> call.
 
-An optional hash reference may be used to pass options.  The only option is
-C<locked>.  If true, handles opened for writing, appending or read-write are
-locked with C<LOCK_EX>; otherwise, they are locked with C<LOCK_SH>.  When using
-C<locked>, ">" or "+>" modes will delay truncation until after the lock is
-acquired.
+An optional hash reference may be used to pass options.
+
+The C<locked> option governs file locking; if true, handles opened for writing,
+appending or read-write are locked with C<LOCK_EX>; otherwise, they are
+locked with C<LOCK_SH>.  When using C<locked>, ">" or "+>" modes will delay
+truncation until after the lock is acquired.
+
+The C<exclusive> option causes the open() call to fail if the file already
+exists.  This corresponds to the O_EXCL flag to sysopen / open(2).
+C<exclusive> implies C<locked> and will set it for you if you forget it.
 
 See C<openr>, C<openw>, C<openrw>, and C<opena> for sugar.
 
-Current API available since 0.039.
+Current API available since 0.066.
 
 =head2 is_absolute, is_relative
 
@@ -2768,7 +2782,7 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alex Efros Chris Williams David Steinbrunner Doug Bell Gabor Szabo Gabriel Andrade George Hartzell Geraud Continsouzas Goro Fuji Graham Knop Karen Etheridge Martin Kjeldsen Michael G. Schwern regina-verbae Smylers Toby Inkster 김도형 - Keedi Kim
+=for stopwords Alex Efros Chris Williams David Steinbrunner Doug Bell Gabor Szabo Gabriel Andrade George Hartzell Geraud Continsouzas Goro Fuji Graham Knop James Hunt Karen Etheridge Martin Kjeldsen Michael G. Schwern regina-verbae Smylers Toby Inkster 김도형 - Keedi Kim
 
 =over 4
 
@@ -2814,6 +2828,10 @@ Graham Knop <haarg@haarg.org>
 
 =item *
 
+James Hunt <james@niftylogic.com>
+
+=item *
+
 Karen Etheridge <ether@cpan.org>
 
 =item *
